Method: Tinkerforge::BrickletRGBLEDButton#set_bootloader_mode
- Defined in:
- lib/tinkerforge/bricklet_rgb_led_button.rb
#set_bootloader_mode(mode) ⇒ Object
Sets the bootloader mode and returns the status after the requested mode change was instigated.
You can change from bootloader mode to firmware mode and vice versa. A change from bootloader mode to firmware mode will only take place if the entry function, device identifier and CRC are present and correct.
This function is used by Brick Viewer during flashing. It should not be necessary to call it in a normal user program.
157 158 159 160 161 |
# File 'lib/tinkerforge/bricklet_rgb_led_button.rb', line 157 def set_bootloader_mode(mode) check_validity send_request FUNCTION_SET_BOOTLOADER_MODE, [mode], 'C', 9, 'C' end |